﻿using ComPDFKit.PDFDocument;
using ComPDFKit.PDFPage;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml.Linq;

namespace PDF_Office.CustomControl
{
    /// <summary>
    /// PageTurningPreview.xaml 的交互逻辑
    /// </summary>
    public partial class PageTurningPreview : UserControl
    {
        public static CPDFDocument document;
        public PageTurningPreview()
        {
            InitializeComponent();
            if (document!=null) {
                AwaitRenderBitmap(document);
                this.PageIndex.Text = document.PageCount.ToString();
            }
            
        }

        public async Task RenderBitmap(CPDFDocument doc)
        {
            CPDFPage page = new CPDFPage(doc, int.Parse(this.CurrentPage.Text) - 1, true);
            byte[] bmp_data = new byte[(int)page.PageSize.Width * (int)page.PageSize.Height * 4];
            await Task.Run(delegate
            {
                page.RenderPageBitmap(0, 0, (int)page.PageSize.Width, (int)page.PageSize.Height, 0xffffffff, bmp_data, 1);
            });
            PixelFormat fmt = PixelFormats.Bgra32;
            BitmapSource bps = BitmapSource.Create((int)page.PageSize.Width, (int)page.PageSize.Height, 96.0, 96.0, fmt, null, bmp_data, ((int)page.PageSize.Width * fmt.BitsPerPixel + 7) / 8);
            this.Image.Source = bps;
        }
        public async void AwaitRenderBitmap(CPDFDocument doc)
        {
            await RenderBitmap(doc);
        }

        private void PrePage_Click(object sender, RoutedEventArgs e)
        {
            if (int.Parse(this.CurrentPage.Text) > 1)
            {
                int Page = int.Parse(this.CurrentPage.Text);
                this.CurrentPage.Text = (--Page).ToString();
                if (document != null)
                {
                    AwaitRenderBitmap(document);
                }
            }
        }

        private void NextPage_Click(object sender, RoutedEventArgs e)
        {
            if (int.Parse(this.CurrentPage.Text) < document.PageCount)
            {
                int Page = int.Parse(this.CurrentPage.Text);
                this.CurrentPage.Text = (++Page).ToString();
                if (document != null)
                {
                    AwaitRenderBitmap(document);
                }
            }
        }

        private async void CurrentPage_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Enter)
            {
                if (int.Parse(this.CurrentPage.Text) <= document.PageCount && int.Parse(this.CurrentPage.Text) > 0)
                {
                    AwaitRenderBitmap(document);
                }
                else
                {
                    MessageBox.Show("超出页面范围");
                }
            }
        }

        private void CountTextBox_PreviewTextInput(object sender, TextCompositionEventArgs e)
        {
            e.Handled = new Regex("[^0-9]+").IsMatch(e.Text);
        }
    }
}


