﻿using ComPDFKit.PDFDocument;
using ComPDFKitViewer.PdfViewer;
using PDF_Office.Model;
using Prism.Commands;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Linq;
using PDF_Office.Model.HomePageToolsDialogs;
using System.Diagnostics;
using System.Globalization;
using System.Windows;
using static PDF_Office.Model.Dialog.ToolsDialogs.SaftyDialogs.SetPasswordDialogModel;
using System.Windows.Forms;
using DialogResult = Prism.Services.Dialogs.DialogResult;
using PDF_Office.CustomControl;

namespace PDF_Office.ViewModels.Dialog.HomePageToolsDialogs
{
    public class HomePageInsertDialogViewModel : BindableBase,IDialogAware
    {
        private CPDFViewer currentViewer;

        private string saveFilePath { get; set; }

        private HomePageInsertDialogModel insertModel = new HomePageInsertDialogModel();

        public DelegateCommand CancelCommand { get; set; }

        public DelegateCommand InsertCommand { get; set; }

        public DelegateCommand SelectFileCommand { get; set; }

        public DelegateCommand FirstPageCommand { get; set; }

        public DelegateCommand LastPageCommand { get; set; }

        public DelegateCommand CustomPageCommand { get; set; }

        private string selectFilePath = "选择文件";
        public string SelectFilePath
        {
            get { return selectFilePath; }
            set
            {
                SetProperty(ref selectFilePath, value);
            }
        }

        private string pageLocation = "0";
        public string PageLocation
        {
            get { return pageLocation; }
            set
            {
                pageLocation = value;
            }
        }

        private string pageNumber="1";
        public string PageNumber
        {
            get { return pageNumber; }
            set
            {
                SetProperty(ref pageNumber, value);
            }
        }

        private string pageInsertIndex = "1";
        public string PageInsertIndex
        {
            get {
                    return pageInsertIndex; }
            set
            {
                if (int.Parse(pageInsertIndex) > currentViewer.Document.PageCount)
                { pageInsertIndex= currentViewer.Document.PageCount.ToString(); }
                SetProperty(ref pageInsertIndex, value);
            }
        }

        private string firstIsCheck = "True";
        public string FirstIsCheck
        {
            get { return firstIsCheck; }
            set
            {
                SetProperty(ref firstIsCheck, value);
            }
        }

        private string lastIsCheck = "False";
        public string LastIsCheck
        {
            get { return lastIsCheck; }
            set
            {
                SetProperty(ref lastIsCheck, value);
            }
        }

        private string customIsCheck = "False";
        public string CustomIsCheck
        {
            get { return customIsCheck; }
            set
            {
                SetProperty(ref customIsCheck, value);
            }
        }

        private string customIsEnabled = "False";
        public string CustomIsEnabled
        {
            get { return customIsEnabled; }
            set
            {
                SetProperty(ref customIsEnabled, value);
            }
        }

        public HomePageInsertDialogViewModel()
        {
            CancelCommand = new DelegateCommand(cancel);
            InsertCommand = new DelegateCommand(insert);
            SelectFileCommand = new DelegateCommand(selectFile);
            FirstPageCommand = new DelegateCommand(firstPage);
            LastPageCommand = new DelegateCommand(lastPage);
            CustomPageCommand = new DelegateCommand(customPage);
        }

        private void cancel()
        {
            RequestClose.Invoke(new DialogResult(ButtonResult.Cancel));
        }

        private void insert()
        {
            
            CPDFDocument insertdocument = CPDFDocument.InitWithFilePath(insertModel.FilePath);
            if (insertdocument == null)
            {
                Trace.WriteLine("Document==null");
                //TODO
                return;
            }
            if (insertdocument.IsEncrypted) {
                Trace.WriteLine("youmima");
                //TODO
                return;
            }
            if (PageLocation == "1") {
                insertModel.InsertIndex=insertModel.InsertIndex - 1;
            }
            currentViewer.Document.ImportPagesAtIndex(insertdocument, insertModel.InserPageRange(insertdocument), insertModel.InsertIndex);
            currentViewer.UndoManager.ClearHistory();
            currentViewer.UndoManager.CanSave = true;
            currentViewer.ReloadDocument();
            currentViewer.Document.WriteToLoadedPath();
            insertdocument.Release();
            System.Diagnostics.Process.Start("Explorer", "/select," + currentViewer.Document.FilePath);
            RequestClose.Invoke(new DialogResult(ButtonResult.OK));
        }

        private void selectFile() {
            System.Windows.Forms.OpenFileDialog dlg = new System.Windows.Forms.OpenFileDialog();
            dlg.Multiselect = false;
            dlg.Filter = "PDF|*.pdf;*.PDF;";
            if (dlg.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                insertModel.FilePath= dlg.FileName;
                SelectFilePath = dlg.FileName;
            }

        }

        private void firstPage()
        {
            insertModel.InsertIndex = 1;
            CustomIsEnabled = "False";
            FirstIsCheck = "True";
            LastIsCheck = "False";
            CustomIsCheck = "False";
        }

        private void lastPage()
        {
            insertModel.InsertIndex = currentViewer.Document.PageCount;
            CustomIsEnabled = "False";
            FirstIsCheck = "False";
            LastIsCheck = "True";
            CustomIsCheck = "False";
        }

        private void customPage()
        {
            CustomIsEnabled = "True";
            FirstIsCheck = "False";
            LastIsCheck = "False";
            CustomIsCheck = "True";
        }

        public string Title => "";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {
        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            CPDFViewer viewer = null;
            string filepath = "";
            parameters.TryGetValue<CPDFViewer>(ParameterNames.PDFViewer, out viewer);
            parameters.TryGetValue<string>(ParameterNames.FilePath, out filepath);
            if (viewer != null && viewer.Document != null)
            {
                currentViewer = viewer;
                saveFilePath = filepath;
                PageNumber=currentViewer.Document.PageCount.ToString();
                PageTurningPreview.document = currentViewer.Document;
            }
        }
    }
}
